% IMPORT_DATA   Script importing the raw data of the FDBK1 experiment.
%
% See also DATA_BY_SBJ, CROSSCHECK_TIMES

% File:       fdbk1/data/import_data.m
% Programmer: Alexander Petrov (apetrov+@andrew.cmu.edu)
% Depends-on: nil
% Created:    24 April 2001

%%%%%%%%%%%%%%%%%  Read the raw ASCII file

fprintf(1,'\nLoading ASCII file RAW_DATA.DAT.  Please wait...\n') ;
load raw_data.dat -ascii ;
[rows cols] = size(raw_data) ;
fprintf(1,'\n%d rows and %d columns loaded.\n',rows,cols) ;

% Do a (superficial) consistency check
if (find(isnan(raw_data)))
  warning ('NaNs found in raw_data. Check the raw ASCII file.') ;
else
  fprintf(1,'The RAW_DATA matrix contains no missing values.\n') ;
end;


%%%%%%%%%%%%%%%%%  Slice the big matrix into variables
fprintf(1,'\nSlicing the big matrix into variables, columnwise:\n') ;

% Description of the subject: columns 1 and 2
sbj   = raw_data(:,1) ;     % subject number
group = raw_data(:,2) ;     % group number
fprintf(1,'  Extracted variables SBJ and GROUP.\n') ;

% Absolute time since the beginning of experiment: column 3
clock = raw_data(:,3) ;
fprintf(1,'  Extracted variable CLOCK.\n') ;

% Trial number: column 5
tr = raw_data(:,5) ;
fprintf(1,'  Extracted variable TR (trial number).\n') ;

% Stimulus presentation schedule: column 6
schdl = raw_data(:,6) ;
fprintf(1,'  Extracted variable SCHDL (presentation schedule).\n') ;

% Description of the stimulus: columns 7-11
dist = raw_data(:,7) ;      % distance [420 460 500 540 580 620 660]
categ = raw_data(:,8) ;     % category [1 2 ... 7]
coor = raw_data(:,9:11);    % dot coordinates  [X1 X2 Y]
fdbk = raw_data(:,12) ;     % feedback [0 1 2 ... 7]
fprintf(1,'  Extracted variables DIST, CATEG, COOR, and FDBK.\n') ;

% Assert: X2 = X1 + dist.
if (any(coor(:,1)+dist ~= coor(:,2)))
  warning('There are cases for which X2 ~= X1 + DIST.') ;
end

% Responses obtained from the subject: columns 13-15
OK   = raw_data(:,13) ;     % successful-trial-p
resp = raw_data(:,14) ;     % scale value (from 1 to 9, 0=miss)
RT   = raw_data(:,15) ;     % response time [msec]
fprintf(1,'  Extracted variables OK, RESP, and RT.\n') ;


% Subblocks
% From the subject's point of view the experiment consists
% of 9 blocks of 50 trials each. There were short rest periods
% b/n the blocks. In the program that administers the expmt
% and writes the raw data file, these are called subblocks.
subblock = raw_data(:,4) ;  % subblock_number
fprintf(1,'  Extracted variable SUBBLOCK.\n') ;


%%%%%%%%%%%%%%%%%  Clear

clear raw_data rows cols ;
fprintf(1,'Cleared the big matrix RAW_DATA.\n\n') ;

fprintf(1,'The workspace now contains the following variables:\n\n') ;
whos

%%%%% End of IMPORT_DATA.M
