function  [grARL,ARL,Kargs] = run_ANCHOR_fdbk1(varargin)

% RUN_ANCHOR_FDBK1 -- Run the ANCHOR model through FDBK1 experiment
%
% [grARL,ARL,Kargs] = run_ANCHOR_fdbk1(key1,val1,...)
% [grARL,ARL,Kargs] = run_ANCHOR_fdbk1(Kargs)
%
% All arguments are keyword arguments (see KEYARGIN):
%  * 'model_params' -- defaults to a version of ANCHOR_PARAMS
%  * 'groups' -- row vector, default [1 2 3 4 5 6], see MAKE_FDBK1_STIMULI
%  * 'N_runs' -- per group, default = 10
%  * 'stim' -- a cell array of [N_trials,N_runs] matrices, one per group
%  * 'fdbk' -- same size as 'stim', both generated by MAKE_FDBK1_STIMULI
%  * 'ARL_params' -- default [], which means to use FDBK1_ARL2's defaults
%
% ARL is a cell array of [N_blocks,N_runs] matrices, one per group
% grARL is a [N_blocks,N_groups] matrix of group-averaged ARLs
% Kargs is a structure with all keyword arguments. Can be passed
% to RUN_ANCHOR_FDBK1 to repeat the run with the same parameters.
%
% See also ANCHOR2, MAKE_FDBK1_STIMULI, FDBK1_ARL2, RUN_INST_FDBK1.

% Original coding by Alex Petrov, Ohio State University
% $Revision: 1.1 $  $Date: 2007-08-17 $


%-- Parse keyword arguments
if (nargin==1)  % Karg structure passed explicitly
    Kargs = varargin{1} ;
else    % keyword args passed as <'key',value> pairs
    %- Make defaults
    model_params = anchor_params ;
    model_params.N_cat = 7 ;
    model_params.anchors = default_anchors([.420 .660],7) ;
    model_params.avail = [1:7]' ;
    model_params.history = .040 ;
    model_params.cutoffs = .80 .* [-3 -1 +1 +3] ;
    defaults.model_params = model_params ;
    defaults.groups = [1 2 3 4 5 6] ;
    defaults.N_runs = 10 ;
    defaults.stim = [] ;
    defaults.fdbk = [] ;
    defaults.ARL_params = [] ;
    %- Override defaults by supplied keyword args
    Kargs = keyargin(varargin,defaults) ;
end

model_params = Kargs.model_params ;
groups = fliplr(Kargs.groups) ;   % will preallocate memory in FOR loop
if (isempty(Kargs.stim))
    N_runs = Kargs.N_runs ;
    for k = groups
        [stim{k},categ{k},fdbk{k}] = make_fdbk1_stimuli(k,N_runs) ;
    end
else  % STIM and FDBK supplied explicitly
    stim = Kargs.stim ;
    fdbk = Kargs.fdbk ;
    N_runs = size(stim{1},2) ;
end
ARL_params = Kargs.ARL_params ;


%-- Run ANCHOR and calculate ARL profiles
for k = groups
    mresp = anchor2(stim{k},model_params,fdbk{k}) ;
    [ARL{k},ARL_params] = fdbk1_ARL2(stim{k},mresp,ARL_params) ;
    grARL(:,k) = mean(ARL{k},2) ;
end
Kargs.ARL_params = ARL_params ;

%---  Return GRARL, ARL, and KARGS
%%%%% End of file RUN_ANCHOR_FDBK1.M
