function  chev = make_protoanchor_chev(N_trials,N_runs)

% MAKE_PROTOANCHOR_CHEV -- Generate "chance events" for PROTOANCHOR_CHEV
%
%  chev = make_protoanchor_chev(N_trials,N_runs)
%
%  CHEV is a "chance event" structure suitable for passing to
%  PROTOANCHOR_CHEV. It has the following fields:
%   * target_mag_noise -- normrnd(zeros(N_trials,N_runs),1)
%   * inst_mag_noise -- [N_trials,1] cell vector of normrnd matrices
%   * softmax1_noise -- rand(N_trials,N_runs)
%
%  See also PROTOANCHOR_CHEV, RAND, SOFTMAX1_CHEV.

% Original coding by Alex Petrov, Ohio State University
% $Revision: 1.0 $  $Date: 2007-08-14 $
%
% Copyright (c) Alexander Petrov 1999-2007, http://alexpetrov.com
% Please read the LICENSE and NO WARRANTY statement in anchor_license.m

%-- Gaussian noise to the target magnitudes
% Usage:  
%  nn = 1 + perc_k .* target_mag_noise ;
%  mags = mags .* nn ;
chev.target_mag_noise = normrnd(zeros(N_trials,N_runs),1) ;

%-- Gaussian noise to the instance magnitudes
% Usage:
%  nn = 1 + mem_k .* inst_mag_noise{trial}(1:M,run)
%  noisy_inst_mags = inst_mags(1:M) .* nn ;
max_seed = 9 ;     % should be size(protoanchor_params.instances,1)
X = cell(N_trials,1) ;
for k = 1:N_trials
    X{k} = normrnd(zeros(max_seed+k,N_runs),1) ;
end
chev.inst_mag_noise = X ;

%-- Uniform noise for use in SOFTMAX1_CHEV
% Usage:
%   ... = softmax1_chev(scores,temper,softmax1_noise(trial,run)) ;
chev.softmax1_chev = rand(N_trials,N_runs) ;

%--- Return CHEV
%%%%% End of file MAKE_PROTOANCHOR_CHEV.M
